swapimpl.o swapimpl.d : ../../../icu/source/tools/toolutil/swapimpl.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/uinvchar.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/uarrsort.h \
 ../../../icu/source/common/ucmndata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/umapfile.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/ulayout_props.h \
 ../../../icu/source/common/emojiprops.h \
 ../../../icu/source/common/unicode/ucptrie.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/uset_imp.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/uresdata.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/unicode/uloc.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/resource.h \
 ../../../icu/source/common/restrace.h \
 ../../../icu/source/common/ucnv_io.h ../../../icu/source/common/uprops.h \
 ../../../icu/source/common/ucase.h ../../../icu/source/common/utrie2.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/ubidi_props.h \
 ../../../icu/source/common/ucol_swp.h \
 ../../../icu/source/common/ucnv_bld.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/ucnv_cnv.h \
 ../../../icu/source/common/ucnvmbcs.h \
 ../../../icu/source/common/ucnv_ext.h \
 ../../../icu/source/common/unormimp.h \
 ../../../icu/source/common/normalizer2impl.h \
 ../../../icu/source/common/unicode/normalizer2.h \
 ../../../icu/source/common/unicode/uniset.h \
 ../../../icu/source/common/unicode/unifilt.h \
 ../../../icu/source/common/unicode/unifunct.h \
 ../../../icu/source/common/unicode/unimatch.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/unorm2.h \
 ../../../icu/source/common/unicode/unorm.h \
 ../../../icu/source/common/unicode/uiter.h \
 ../../../icu/source/common/mutex.h ../../../icu/source/common/umutex.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/common/sprpimpl.h \
 ../../../icu/source/common/unicode/ustring.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/common/unicode/usprep.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/common/utrie.h \
 ../../../icu/source/common/ubidi_props.h \
 ../../../icu/source/common/propname.h \
 ../../../icu/source/common/unicode/bytestrie.h \
 ../../../icu/source/common/unicode/ustringtrie.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/uprops.h \
 ../../../icu/source/common/rbbidata.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/utrie.h ../../../icu/source/common/utrie2.h \
 ../../../icu/source/common/dictionarydata.h \
 ../../../icu/source/common/unicode/utext.h \
 ../../../icu/source/common/unicode/chariter.h \
 ../../../icu/source/common/unicode/ustringtrie.h \
 ../../../icu/source/i18n/uspoof_impl.h \
 ../../../icu/source/i18n/unicode/uspoof.h \
 ../../../icu/source/common/unicode/ubidi.h \
 ../../../icu/source/common/unicode/uscript.h \
 ../../../icu/source/common/capi_helper.h \
 ../../../icu/source/common/umutex.h
