gencnval.o gencnval.d : ../../../icu/source/tools/gencnval/gencnval.c \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/ucnv_io.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/uinvchar.h \
 ../../../icu/source/tools/gencnval/../toolutil/filestrm.h \
 ../../../icu/source/tools/gencnval/../toolutil/toolutil.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/tools/gencnval/../toolutil/unewdata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/tools/gencnval/../toolutil/uoptions.h
