parse.o parse.d : ../../../icu/source/tools/genrb/parse.cpp \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/tools/genrb/parse.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/tools/genrb/../toolutil/filestrm.h \
 ../../../icu/source/tools/genrb/../toolutil/ucbuf.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/tools/genrb/../toolutil/filestrm.h \
 ../../../icu/source/tools/genrb/errmsg.h \
 ../../../icu/source/common/uhash.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/uelement.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/uinvchar.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/tools/genrb/read.h \
 ../../../icu/source/tools/genrb/ustr.h \
 ../../../icu/source/tools/genrb/reslist.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/unicode/uloc.h \
 ../../../icu/source/common/unicode/ustring.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/uiter.h \
 ../../../icu/source/tools/genrb/../toolutil/unewdata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/uresdata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/unicode/ures.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/resource.h \
 ../../../icu/source/common/restrace.h \
 ../../../icu/source/i18n/rbt_pars.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/common/unicode/unorm.h \
 ../../../icu/source/common/unicode/unorm2.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/i18n/rbt.h \
 ../../../icu/source/i18n/unicode/translit.h \
 ../../../icu/source/i18n/unicode/utrans.h \
 ../../../icu/source/common/unicode/urep.h \
 ../../../icu/source/common/unicode/strenum.h \
 ../../../icu/source/common/hash.h ../../../icu/source/common/uhash.h \
 ../../../icu/source/common/uvector.h \
 ../../../icu/source/common/uarrsort.h \
 ../../../icu/source/tools/genrb/genrb.h \
 ../../../icu/source/tools/genrb/rbutil.h \
 ../../../icu/source/tools/genrb/../toolutil/toolutil.h \
 ../../../icu/source/common/unicode/errorcode.h \
 ../../../icu/source/tools/genrb/../toolutil/uoptions.h \
 ../../../icu/source/i18n/unicode/ucol.h \
 ../../../icu/source/common/unicode/uscript.h \
 ../../../icu/source/common/unicode/normalizer2.h \
 ../../../icu/source/common/unicode/uniset.h \
 ../../../icu/source/common/unicode/unifilt.h \
 ../../../icu/source/common/unicode/unifunct.h \
 ../../../icu/source/common/unicode/unimatch.h \
 ../../../icu/source/common/charstr.h \
 ../../../icu/source/i18n/collationbuilder.h \
 ../../../icu/source/i18n/collationrootelements.h \
 ../../../icu/source/i18n/collation.h \
 ../../../icu/source/i18n/collationruleparser.h \
 ../../../icu/source/i18n/unicode/ucol.h \
 ../../../icu/source/common/uvectr32.h \
 ../../../icu/source/common/uvectr64.h \
 ../../../icu/source/i18n/collationdata.h \
 ../../../icu/source/common/normalizer2impl.h \
 ../../../icu/source/common/unicode/normalizer2.h \
 ../../../icu/source/common/unicode/ucptrie.h \
 ../../../icu/source/common/unicode/unorm.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/mutex.h ../../../icu/source/common/umutex.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/common/uset_imp.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/utrie2.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/i18n/collationdatareader.h \
 ../../../icu/source/i18n/collationdatawriter.h \
 ../../../icu/source/i18n/collationfastlatinbuilder.h \
 ../../../icu/source/i18n/collationfastlatin.h \
 ../../../icu/source/tools/genrb/../toolutil/collationinfo.h \
 ../../../icu/source/i18n/collationroot.h \
 ../../../icu/source/i18n/collationruleparser.h \
 ../../../icu/source/i18n/collationtailoring.h \
 ../../../icu/source/common/unicode/locid.h \
 ../../../icu/source/i18n/collationsettings.h \
 ../../../icu/source/common/sharedobject.h \
 ../../../icu/source/common/umutex.h \
 ../../../icu/source/common/unifiedcache.h \
 ../../../icu/source/common/utypeinfo.h \
 ../../../icu/source/common/unicode/locid.h \
 ../../../icu/source/common/sharedobject.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/ustr_imp.h \
 ../../../icu/source/tools/genrb/../toolutil/writesrc.h \
 ../../../icu/source/common/unicode/ucptrie.h \
 ../../../icu/source/common/unicode/umutablecptrie.h
