genmbcs.o genmbcs.d : ../../../icu/source/tools/makeconv/genmbcs.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/common/cstring.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/tools/makeconv/../toolutil/unewdata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/ucnv_cnv.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/uset.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/uset_imp.h \
 ../../../icu/source/common/ucnvmbcs.h \
 ../../../icu/source/common/ucnv_cnv.h \
 ../../../icu/source/common/ucnv_ext.h \
 ../../../icu/source/tools/makeconv/../toolutil/ucm.h \
 ../../../icu/source/common/ucnv_ext.h \
 ../../../icu/source/tools/makeconv/../toolutil/filestrm.h \
 ../../../icu/source/tools/makeconv/makeconv.h \
 ../../../icu/source/common/ucnv_bld.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/ucnvmbcs.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/tools/makeconv/genmbcs.h \
 ../../../icu/source/tools/makeconv/../toolutil/toolutil.h \
 ../../../icu/source/common/unicode/errorcode.h \
 ../../../icu/source/common/unicode/uobject.h
