genbrk.o genbrk.d : ../../../icu/source/tools/genbrk/genbrk.cpp \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/unicode/umachine.h \
 ../../../icu/source/common/unicode/ptypes.h \
 ../../../icu/source/common/unicode/platform.h \
 ../../../icu/source/common/unicode/uconfig.h \
 ../../../icu/source/common/unicode/uvernum.h \
 ../../../icu/source/common/unicode/urename.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/unicode/utf.h \
 ../../../icu/source/common/unicode/utf8.h \
 ../../../icu/source/common/unicode/utf16.h \
 ../../../icu/source/common/unicode/utf_old.h \
 ../../../icu/source/common/unicode/ucnv.h \
 ../../../icu/source/common/unicode/ucnv_err.h \
 ../../../icu/source/common/unicode/uenum.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/char16ptr.h \
 ../../../icu/source/common/unicode/rep.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/std_string.h \
 ../../../icu/source/common/unicode/stringpiece.h \
 ../../../icu/source/common/unicode/bytestream.h \
 ../../../icu/source/common/unicode/rbbi.h \
 ../../../icu/source/common/unicode/brkiter.h \
 ../../../icu/source/common/unicode/chariter.h \
 ../../../icu/source/common/unicode/locid.h \
 ../../../icu/source/common/unicode/strenum.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/unicode/uloc.h \
 ../../../icu/source/common/unicode/ubrk.h \
 ../../../icu/source/common/unicode/utext.h \
 ../../../icu/source/common/unicode/uchar.h \
 ../../../icu/source/common/unicode/stringoptions.h \
 ../../../icu/source/common/unicode/ucpmap.h \
 ../../../icu/source/common/unicode/parseerr.h \
 ../../../icu/source/common/unicode/umisc.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/unicode/schriter.h \
 ../../../icu/source/common/unicode/uchriter.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/tools/genbrk/../toolutil/uoptions.h \
 ../../../icu/source/tools/genbrk/../toolutil/unewdata.h \
 ../../../icu/source/common/ucmndata.h \
 ../../../icu/source/common/unicode/udata.h \
 ../../../icu/source/common/umapfile.h \
 ../../../icu/source/common/unicode/putil.h \
 ../../../icu/source/common/putilimp.h \
 ../../../icu/source/common/unicode/utypes.h \
 ../../../icu/source/common/rbbidata.h \
 ../../../icu/source/common/udataswp.h \
 ../../../icu/source/common/unicode/ucptrie.h \
 ../../../icu/source/common/unicode/uobject.h \
 ../../../icu/source/common/unicode/unistr.h \
 ../../../icu/source/common/unicode/uversion.h \
 ../../../icu/source/common/umutex.h \
 ../../../icu/source/common/unicode/uclean.h \
 ../../../icu/source/common/cmemory.h \
 ../../../icu/source/common/unicode/localpointer.h \
 ../../../icu/source/common/uassert.h
